California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 86 - TAX ON CIGARETTES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278256 | YES ON PROPOSITION 86 - A COALITION OF HEALTH ORGANIZATIONS PROMOTING DISEASE RESEARCH, TOBACCO CONTROL, EMERGENCY CARE AND CHILDREN'S HEALTH SERVICES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1286420 | NO ON PROPOSITION 86, CALIFORNIANS AGAINST UNACCOUNTABLE TAXES, A COALITION OF TAXPAYERS, BUSINESSES AND LAW ENFORCEMENT | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287395 | NO ON 86 - STOP THE $2 BILLION TAX HIKE, A COALITION OF BUSINESS, LAW ENFORCEMENT AND TAXPAYER GROUPS AND PHILIP MORRIS USA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1290881 | PHYSICIANS AGAINST PROPOSITION 86, SPONSORED BY GROCERY DISTRIBUTORS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1289296 | CALIFORNIA ASSOCIATION OF LIBERTY AND CHOICE, NO ON PROP. 86 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1291766 | TOBACCO - FREE KIDS ACTION FUND (YES ON 86) | SUPPORT